Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(749)

Unified Diff: net/url_request/url_request_job.cc

Issue 5384002: net: Remove typedef net::URLRequest URLRequest; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/url_request/url_request_job.cc
diff --git a/net/url_request/url_request_job.cc b/net/url_request/url_request_job.cc
index a059a006a925d6e1897120bce65946942c9fcaed..f8a7ff456a2f2599b2ffcd54e0e76a7f95b60567 100644
--- a/net/url_request/url_request_job.cc
+++ b/net/url_request/url_request_job.cc
@@ -25,7 +25,7 @@ using base::TimeTicks;
// static
const int URLRequestJob::kFilterBufSize = 32 * 1024;
-URLRequestJob::URLRequestJob(URLRequest* request)
+URLRequestJob::URLRequestJob(net::URLRequest* request)
wtc 2010/11/30 19:29:08 Instead of adding net:: to this file, please put t
tfarina 2010/11/30 21:46:09 Done.
: request_(request),
prefilter_bytes_read_(0),
postfilter_bytes_read_(0),
@@ -443,7 +443,7 @@ void URLRequestJob::NotifyHeadersComplete() {
// Initialize to the current time, and let the subclass optionally override
// the time stamps if it has that information. The default request_time is
// set by URLRequest before it calls our Start method.
request_->response_info_.response_time = Time::Now();
GetResponseInfo(&request_->response_info_);
@@ -443,7 +443,7 @@ void URLRequestJob::NotifyHeadersComplete() {
// Initialize to the current time, and let the subclass optionally override
// the time stamps if it has that information. The default request_time is
- // set by URLRequest before it calls our Start method.
+ // set by net::URLRequest before it calls our Start method.
request_->response_info_.response_time = Time::Now();
GetResponseInfo(&request_->response_info_);

Powered by Google App Engine
This is Rietveld 408576698